pub struct SQLiteConnection { /* private fields */ }Trait Implementations
Sourceimpl Connection for SQLiteConnection
impl Connection for SQLiteConnection
Sourceasync fn connect(url: Cow<'static, str>) -> Result<SQLiteConnection>
async fn connect(url: Cow<'static, str>) -> Result<SQLiteConnection>
Create a connection (or pool) with at least one underlying session
established to the given URL.
Sourcefn begin(&mut self) -> impl Future<Output = Result<SQLiteTransaction<'_>>>
fn begin(&mut self) -> impl Future<Output = Result<SQLiteTransaction<'_>>>
Begin a transaction scope tied to the current connection.
fn disconnect(self) -> impl Future<Output = Result<(), Error>>
Sourceimpl Executor for SQLiteConnection
impl Executor for SQLiteConnection
Sourcetype Driver = SQLiteDriver
type Driver = SQLiteDriver
Underlying driver type supplying SQL dialect + I/O.
Sourceasync fn prepare(&mut self, sql: String) -> Result<Query<Self::Driver>>
async fn prepare(&mut self, sql: String) -> Result<Query<Self::Driver>>
Prepare a query (e.g. statement caching / parameter binding) returning a
Query. Read moreSourcefn run<'s>(
&'s mut self,
query: impl AsQuery<Self::Driver> + 's,
) -> impl Stream<Item = Result<QueryResult>> + Send
fn run<'s>( &'s mut self, query: impl AsQuery<Self::Driver> + 's, ) -> impl Stream<Item = Result<QueryResult>> + Send
Run an already prepared query, streaming heterogeneous
QueryResult items. Read moreSourcefn fetch<'s>(
&'s mut self,
query: impl AsQuery<Self::Driver> + 's,
) -> impl Stream<Item = Result<RowLabeled, Error>> + Send + 's
fn fetch<'s>( &'s mut self, query: impl AsQuery<Self::Driver> + 's, ) -> impl Stream<Item = Result<RowLabeled, Error>> + Send + 's
Run a query and stream only labeled rows, filtering out non-row results. Read more