pub struct SQLitePrepared { /* private fields */ }Expand description
Prepared statement wrapper for SQLite.
Manages the native statement pointer and binding index, and implements the Prepared trait to bind parameters from tank_core::Value.
Implementations
Sourceimpl SQLitePrepared
impl SQLitePrepared
pub fn last_error(&self) -> String